summaryrefslogtreecommitdiff
path: root/src/cython
diff options
context:
space:
mode:
Diffstat (limited to 'src/cython')
-rwxr-xr-xsrc/cython/cython/persistence_graphical_tools.py14
-rw-r--r--src/cython/doc/persistence_graphical_tools_user.rst2
2 files changed, 8 insertions, 8 deletions
diff --git a/src/cython/doc/persistence_graphical_tools_user.rst b/src/cython/doc/persistence_graphical_tools_user.rst
index 0047f9c8..fda086c3 100644
--- a/src/cython/doc/persistence_graphical_tools_user.rst
+++ b/src/cython/doc/persistence_graphical_tools_user.rst
@@ -60,5 +60,5 @@ If you want more information on a specific dimension, for instance:
persistence_file=gudhi.__root_source_dir__ + \
'/data/persistence_diagram/rips_on_tore3D_1307.pers'
plt = gudhi.plot_persistence_density(persistence_file=persistence_file,
- max_plots=0, dimension=1, legend=True)
+ max_intervals=0, dimension=1, legend=True)
plt.show()
diff --git a/src/cython/cython/persistence_graphical_tools.py b/src/cython/cython/persistence_graphical_tools.py
index 4c8467bd..96b579bd 100755
--- a/src/cython/cython/persistence_graphical_tools.py
+++ b/src/cython/cython/persistence_graphical_tools.py
@@ -250,10 +250,10 @@ try:
(default), 'scott' is used. See scipy.stats.gaussian_kde
documentation for more details.
:type bw_method: str, scalar or callable, optional.
- :param max_plots: maximal number of points to display. Selected points
- are those with the longest life time. Set it to 0 to see all,
- default value is 1000.
- :type max_plots: int.
+ :param max_intervals: maximal number of intervals to display.
+ Selected points are those with the longest life time. Set it
+ to 0 to see all. Default value is 1000.
+ :type max_intervals: int.
:param dimension: the dimension to be selected in the intervals
(default is None to mix all dimensions).
:type dimension: int.
@@ -283,11 +283,11 @@ try:
else:
persistence_dim = persistence
- if max_plots > 0 and max_plots < len(persistence_dim):
- # Sort by life time, then takes only the max_plots elements
+ if max_intervals > 0 and max_intervals < len(persistence_dim):
+ # Sort by life time, then takes only the max_intervals elements
persistence_dim = sorted(persistence_dim,
key=lambda life_time: life_time[1][1]-life_time[1][0],
- reverse=True)[:max_plots]
+ reverse=True)[:max_intervals]
# Set as numpy array birth and death (remove undefined values - inf and NaN)
birth = np.asarray([(interval[1][0]) for interval in persistence_dim if (math.isfinite(interval[1][1]) and math.isfinite(interval[1][0]))])